# eigenrules

Powered by [eigendata.ai](https://eigendata.ai)

# installation

`pip install eigenrules`

or

`poetry add eigenrules`

# usage

please refer to the [examples folder](./examples/) for usage examples
